DEREncoding

Enum DEREncoding 

pub enum DEREncoding {
Show 16 variants NotApplicable, Valid, SigTooShort, SigTooLong, NoCompoundMarker, InvalidCompoundLengthDescriptor, NoSValueLengthDescriptor, DescribedLengthMismatch, RElementNotAnInteger, RLengthIsZero, NegativeRValue, NullByteAtRValueStart, SElementNotAnInteger, SLengthIsZero, NegativeSValue, NullByteAtSValueStart,
}

Variants



NotApplicable

The signature is not meant to be DER encoded. This is the case for e.g. Schnorr signatures.



Valid

The ECDSA signature is DER encoded.



SigTooShort

The ECDSA signature is too short to be DER encoded.



SigTooLong

The ECDSA signature is too long to be DER encoded.



NoCompoundMarker

The ECDSA signature does not have a compound marker.



InvalidCompoundLengthDescriptor

The compound length descriptor does not match the signature length.



NoSValueLengthDescriptor

The ECDSA signature does not have a S-value length descriptor.



DescribedLengthMismatch

The encoded length of the r + S-value + markers + descriptors doesn’t match the signature length.



RElementNotAnInteger

The R element marker does not indicate an integer.



RLengthIsZero

The R element length is zero.



NegativeRValue

The R element is negative.



NullByteAtRValueStart

The R element starts with a NULL byte.



SElementNotAnInteger

The S element marker does not indicate an integer.



SLengthIsZero

The S element length is zero.



NegativeSValue

The S element is negative.



NullByteAtSValueStart

The S element starts with a NULL byte.