Signature

Trait Signature 

pub trait Signature {
    // Required methods
    fn is_ecdsa_signature(&self, strict_der: bool) -> bool;
    fn is_schnorr_signature(&self) -> bool;

    // Provided method
    fn is_signature(&self) -> bool { ... }
}

Required Methods

fn is_ecdsa_signature(&self, strict_der: bool) -> bool

Checks if the underlying bytes represent a Bitcoin ECDSA signature. This function expects that the SigHash is included.

fn is_schnorr_signature(&self) -> bool

Checks if the underlying bytes represent a Bitcoin Schnoor signature. This function expects that the SigHash is included.

Provided Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Signature for Instruction<'_>

Source

impl Signature for Vec<u8>

Source

impl Signature for [u8]

Implementors